from setuptools import setup,find_packages

setup(
    name = "sunji3",
    version = "0.0.2",
    packages = find_packages(),
    descripion = "This is a demo",
    author = "lian.he",
    author_email = "327842846@qq.com",
    url = "https://github.com/hlzy/mutl_repo",
#    install_requires="sunji",
    )
